@@ -13,6 +13,18 @@ def check_date_arg(value, arg_name=None):
             raise ValueError("Option '%s' must be in YYYYMMDD format, input is '%s'" % (arg_name, value))
 
 
+def parse_limit_arg(value):
+    if value:
+        tokens = value.split(',')
+        try:
+            if len(tokens) != 2:
+                raise ValueError
+            return int(tokens[0]), int(tokens[1])
+        except ValueError:
+            raise ValueError("Option 'limit' must be in START,COUNT format, input is '%s'" % value)
+    return 0, None
+
+
 def load_symbols(file_path):
     symbols = []
     with open(file_path) as f:
